@@ -30,7 +30,6 @@
 (require 'org-agenda)
 
 (require 'org-gtd-core)
-(require 'org-gtd-id)
 (require 'org-gtd-wip)
 (require 'org-gtd-horizons)
 
@@ -273,7 +272,7 @@ WINDOW-CONFIG is the window config to set after clarification finishes."
     (if buf-names
         (let ((chosen-buf-name (completing-read "Choose a buffer: " buf-names nil t)))
           (org-gtd-clarify-setup-windows chosen-buf-name))
-      (message "There are no Org GTD WIP buffers."))))
+      (message "There are no Org-GTD WIP buffers."))))
 
 (defun org-gtd-clarify-toggle-horizons-window ()
   "Toggle the window with the horizons buffer."
@@ -286,32 +285,36 @@ WINDOW-CONFIG is the window config to set after clarification finishes."
 
 (defun org-gtd-clarify-stop ()
   "Stop clarifying the current item and restore previous state.
-If there are pending duplicates in the queue, discards only the current
-item and moves to the next queued item. Otherwise restores the window
-configuration and cleans up."
+Closes the horizons view, restores the window configuration,
+cleans up temp file, and kills the WIP buffer without organizing the item.
+If there are pending duplicates, prompts whether to discard or save them."
   (interactive)
-  (let ((queue (copy-sequence org-gtd-clarify--duplicate-queue))
-        (window-config org-gtd-clarify--window-config)
+  ;; Handle pending duplicates first
+  (when (and (boundp 'org-gtd-clarify--duplicate-queue)
+             (not (org-gtd-clarify--queue-empty-p)))
+    (pcase (org-gtd-clarify--prompt-queue-action)
+      ('save (org-gtd-clarify--queue-save-to-inbox))
+      ('cancel (keyboard-quit))
+      ('discard nil)))  ; Just continue with cleanup
+
+  (let ((window-config org-gtd-clarify--window-config)
         (task-id org-gtd-clarify--clarify-id)
-        (continuation org-gtd-clarify--continuation)
         (inbox-p org-gtd-clarify--inbox-p))
-    ;; Clear queue on current buffer so kill hooks don't prompt
-    (setq org-gtd-clarify--duplicate-queue nil)
-    (if queue
-        ;; Queue has items — discard current, process next
-        (org-gtd-clarify--process-next-queued-item
-         queue window-config continuation task-id)
-      ;; No queue — full cleanup
-      (org-gtd-clarify--queue-cleanup)
-      (org-gtd-clarify--cleanup-horizons-view)
-      (when task-id
-        (org-gtd-wip--cleanup-temp-file task-id))
-      (when inbox-p
-        (setq org-gtd-process--session-active nil
-              org-gtd-process--pending-inboxes nil))
-      (when window-config
-        (set-window-configuration window-config))
-      (message "Stopped clarifying"))))
+    ;; Clean up queue display
+    (org-gtd-clarify--queue-cleanup)
+    ;; Clean up horizons view
+    (org-gtd-clarify--cleanup-horizons-view)
+    ;; Clean up temp file and kill buffer
+    (when task-id
+      (org-gtd-wip--cleanup-temp-file task-id))
+    ;; Clear inbox processing session state if we were processing inbox
+    (when inbox-p
+      (setq org-gtd-process--session-active nil
+            org-gtd-process--pending-inboxes nil))
+    ;; Restore window configuration
+    (when window-config
+      (set-window-configuration window-config))
+    (message "Stopped clarifying")))
 
 (defun org-gtd-clarify-duplicate ()
   "Duplicate current item with a new title.
@@ -324,15 +327,8 @@ Prompts for a new title, then adds the duplicate to the queue."
       (user-error "Nothing to duplicate"))
     (let* ((default-title (plist-get content-plist :title))
            (new-title (read-string "Duplicate title: " default-title))
-           (content (plist-get content-plist :content))
-           (updated-content
-            (with-temp-buffer
-              (insert content)
-              (goto-char (point-min))
-              (org-mode)
-              (org-edit-headline new-title)
-              (buffer-string))))
-      (org-gtd-clarify--queue-add new-title updated-content)
+           (content (plist-get content-plist :content)))
+      (org-gtd-clarify--queue-add new-title content)
       (org-gtd-clarify--queue-display)
       (message "Duplicated: %s" new-title))))
 
@@ -626,45 +622,33 @@ Creates or updates the queue buffer with current queue contents."
 
 ;;;;; Queue Processing
 
-(defun org-gtd-clarify--process-next-queued-item (queue window-config continuation old-task-id)
+(defun org-gtd-clarify--process-next-queued-item (queue window-config continuation)
   "Process the next item from the duplicate QUEUE.
 WINDOW-CONFIG is restored after all items are processed.
-CONTINUATION is called after the queue is empty.
-OLD-TASK-ID is the clarify-id of the buffer being reused."
+CONTINUATION is called after the queue is empty."
   (let ((item (pop queue)))
     (if item
         (let* ((content (plist-get item :content))
-               (temp-file (gethash old-task-id org-gtd-wip--temp-files))
-               (processing-buffer (if temp-file
-                                      (find-buffer-visiting temp-file)
-                                    (org-gtd-wip--get-buffer (org-id-new)))))
+               (clarify-id (org-id-new))
+               (processing-buffer (org-gtd-wip--get-buffer clarify-id)))
+          ;; Initialize buffer with queued content
           (with-current-buffer processing-buffer
-            ;; Clear buffer and insert new content
-            (let ((inhibit-read-only t))
-              (erase-buffer))
             (insert content)
             (goto-char (point-min))
-            ;; Delete stale ID from original, generate fresh one
-            (org-entry-delete nil "ID")
-            (let ((new-id (org-gtd-id-get-create)))
-              (org-gtd-wip--rekey old-task-id new-id)
-              ;; Ensure mode is active
-              (unless (derived-mode-p 'org-gtd-clarify-mode)
-                (org-gtd-clarify-mode))
-              ;; Update buffer-local state
-              (setq-local org-gtd-clarify--window-config window-config
-                          org-gtd-clarify--clarify-id new-id
-                          org-gtd-clarify--continuation continuation
-                          org-gtd-clarify--source-heading-marker nil
-                          org-gtd-clarify--skip-refile nil
-                          org-gtd-clarify--duplicate-queue queue))
-            ;; Update queue display or cleanup if empty
+            (unless (derived-mode-p 'org-gtd-clarify-mode)
+              (org-gtd-clarify-mode))
+            (setq-local org-gtd-clarify--window-config window-config
+                        org-gtd-clarify--clarify-id clarify-id
+                        org-gtd-clarify--continuation continuation
+                        org-gtd-clarify--source-heading-marker nil
+                        org-gtd-clarify--duplicate-queue queue))
+          ;; Update queue display or cleanup if empty
+          (with-current-buffer processing-buffer
             (if (org-gtd-clarify--queue-empty-p)
                 (org-gtd-clarify--queue-cleanup)
-              (org-gtd-clarify--queue-display))))
+              (org-gtd-clarify--queue-display)))
+          (org-gtd-clarify-setup-windows processing-buffer))
       ;; No more items - cleanup and continue
-      (when old-task-id
-        (org-gtd-wip--cleanup-temp-file old-task-id))
       (org-gtd-clarify--queue-cleanup)
       (message "All duplicates processed")
       (when window-config
